@@ -21,18 +21,14 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include "info.h"		
 
-#include <QLayout>
-#include <QProcess>
 #include <QLabel>
 #include <QHBoxLayout>
-#include <QTextStream>
 #include <QHeaderView>
 
-#include <kglobalsettings.h>
 #include <kiconloader.h>
-#include <kdialog.h>
 #include <KLocalizedString>
-#include <kdebug.h>
+#include <QDebug>
+#include <QFontDatabase>
 
 KInfoListWidget::KInfoListWidget(const QString &_title, QWidget *parent, bool _getlistbox(QTreeWidget *tree) ) :
 	KCModule(parent), title(_title) {
@@ -47,12 +43,12 @@ KInfoListWidget::KInfoListWidget(const QString &_title, QWidget *parent, bool _g
 	setAboutData(about);
 
 	
-	kDebug() << "Constructing a KInfoListWidget..." << endl;
+	//qDebug() << "Constructing a KInfoListWidget..." << endl;
 
 	//setButtons(KCModule::Help);
 	getlistbox = _getlistbox;
 	QHBoxLayout *layout = new QHBoxLayout(this);
-	layout->setSpacing(KDialog::spacingHint());
+	//PORT QT5 layout->setSpacing(KDialog::spacingHint());
 	layout->setMargin(0);
 	widgetStack = new QStackedWidget(this);
 	layout->addWidget(widgetStack);
@@ -60,7 +56,7 @@ KInfoListWidget::KInfoListWidget(const QString &_title, QWidget *parent, bool _g
 	tree = new QTreeWidget(widgetStack);
 	widgetStack->addWidget(tree);
 	tree->setMinimumSize(200, 120);
-	tree->setFont(KGlobalSettings::generalFont()); /* default font */
+	tree->setFont(QFontDatabase::systemFont(QFontDatabase::GeneralFont)); /* default font */
 	tree->setSortingEnabled(true);
 	tree->setRootIsDecorated(false);
 	tree->header()->setSortIndicatorShown(true);
@@ -75,7 +71,7 @@ KInfoListWidget::KInfoListWidget(const QString &_title, QWidget *parent, bool _g
 }
 
 void KInfoListWidget::load() {
-	kDebug() << "Loading KInfoListWidget..." << endl;
+	//qDebug() << "Loading KInfoListWidget..." << endl;
 
 	//TODO Remove tree content before clear it
 	tree->clear();
